==> odoo_18.1alpha1.20241219.zip: odoo-18.1a1.post20241219/odoo/addons/web/tests/test_perf_load_menu.py <==

import json
from uuid import uuid4

from odoo.tests import common, tagged


@tagged('post_install', '-at_install')
class TestPerfSessionInfo(common.HttpCase):

    def test_performance_session_info(self):
        user = common.new_test_user(
            self.env,
            "session",
            email="session@in.fo",
            tz="UTC",
        )
        self.authenticate(user.login, "info")

        self.env.registry.clear_all_caches()
        # cold ormcache (only web: 42, all module: 113)
        with self.assertQueryCount(113):
            self.url_open(
                "/web/session/get_session_info",
                data=json.dumps({'jsonrpc': "2.0", 'method': "call", 'id': str(uuid4())}),
                headers={"Content-Type": "application/json"},
            )

        # cold fields cache - warm ormcache (only web: 6, all module: 23)
        with self.assertQueryCount(23):
            self.url_open(
                "/web/session/get_session_info",
                data=json.dumps({'jsonrpc': "2.0", 'method': "call", 'id': str(uuid4())}),
                headers={"Content-Type": "application/json"},
            )

    def test_load_web_menus_perf(self):
        self.env.registry.clear_all_caches()
        self.env.invalidate_all()
        # cold orm/fields cache (only web: 10, all module: 40 - no demo)
        with self.assertQueryCount(40):
            self.env['ir.ui.menu'].load_web_menus(False)

        # cold fields cache - warm orm cache (only web: 0, all module: 1)
        self.env.invalidate_all()
        with self.assertQueryCount(1):
            self.env['ir.ui.menu'].load_web_menus(False)

    def test_load_menus_perf(self):
        self.env.registry.clear_all_caches()
        self.env.invalidate_all()
        # cold orm/fields cache (only web: 10, all module: 40 - no demo)
        with self.assertQueryCount(40):
            self.env['ir.ui.menu'].load_menus(False)

        # cold fields cache - warm orm cache (only web: 0, all module: 1)
        self.env.invalidate_all()
        with self.assertQueryCount(1):
            self.env['ir.ui.menu'].load_menus(False)

    def test_visible_menu_ids(self):
        self.env.registry.clear_all_caches()
        self.env.invalidate_all()
        # cold ormcache (only web: 5, all module: 14)
        with self.assertQueryCount(14):
            self.env['ir.ui.menu']._visible_menu_ids()

        # cold fields cache - warm orm cache (only web: 0, all module: 0)
        self.env.invalidate_all()
        with self.assertQueryCount(0):
            self.env['ir.ui.menu']._visible_menu_ids()

==> odoo_18.2alpha1.20250125.zip: odoo-18.2a1.post20250125/odoo/addons/web/tests/test_perf_load_menu.py <==

import json
from uuid import uuid4

from odoo.tests import common, tagged


@tagged('post_install', '-at_install')
class TestPerfSessionInfo(common.HttpCase):

    def test_performance_session_info(self):
        user = common.new_test_user(
            self.env,
            "session",
            email="session@in.fo",
            tz="UTC",
        )
        self.authenticate(user.login, "info")

        self.env.registry.clear_all_caches()
        # cold ormcache (only web: 42, all module: 116)
        with self.assertQueryCount(116):
            self.url_open(
                "/web/session/get_session_info",
                data=json.dumps({'jsonrpc': "2.0", 'method': "call", 'id': str(uuid4())}),
                headers={"Content-Type": "application/json"},
            )

        # cold fields cache - warm ormcache (only web: 6, all module: 25)
        with self.assertQueryCount(25):
            self.url_open(
                "/web/session/get_session_info",
                data=json.dumps({'jsonrpc': "2.0", 'method': "call", 'id': str(uuid4())}),
                headers={"Content-Type": "application/json"},
            )

    def test_load_web_menus_perf(self):
        self.env.registry.clear_all_caches()
        self.env.invalidate_all()
        # cold orm/fields cache (only web: 10, all module: 38 (+3 if not has group account.group_account_readonly); without demo: 40)
        with self.assertQueryCount(41):
            self.env['ir.ui.menu'].load_web_menus(False)

        # cold fields cache - warm orm cache (only web: 0, all module: 1)
        self.env.invalidate_all()
        with self.assertQueryCount(1):
            self.env['ir.ui.menu'].load_web_menus(False)

    def test_load_menus_perf(self):
        self.env.registry.clear_all_caches()
        self.env.invalidate_all()
        # cold orm/fields cache (only web: 10, all module: 38 (+3 if not has group account.group_account_readonly); without demo: 40)
        with self.assertQueryCount(41):
            self.env['ir.ui.menu'].load_menus(False)

        # cold fields cache - warm orm cache (only web: 0, all module: 1)
        self.env.invalidate_all()
        with self.assertQueryCount(1):
            self.env['ir.ui.menu'].load_menus(False)

    def test_visible_menu_ids(self):
        self.env.registry.clear_all_caches()
        self.env.invalidate_all()
        # cold ormcache (only web: 5, all module: 14 (+3 if not has group account.group_account_readonly))
        with self.assertQueryCount(17):
            self.env['ir.ui.menu']._visible_menu_ids()

        # cold fields cache - warm orm cache (only web: 0, all module: 0)
        self.env.invalidate_all()
        with self.assertQueryCount(0):
            self.env['ir.ui.menu']._visible_menu_ids()
